<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>BlockList</name>
    <message>
        <location filename="../BlockList.js" line="+453"/>
        <location line="+41"/>
        <location line="+39"/>
        <source>Block List</source>
        <translation>Lista blocchi</translation>
    </message>
    <message>
        <location line="-80"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <source>Lists</source>
        <translation type="vanished">Liste</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Hide internal blocks</source>
        <translation>Nascondi blocchi interni</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Enable alternating row colors</source>
        <translation>Abilita alternare i colori delle righe</translation>
    </message>
</context>
</TS>
